
> Note: This package is in the dangerous land of `0.x.y` versions and may be subject to breaking
> changes with minor version increments.

# nr.collections

Provides a bunch of useful collection types.

* `ChainDict`: Chain multiple mappings. Mutations affect the first mapping only.
* `HashDict`: Dictionary that uses a custom hash function for its internal keys.
* `LambdaDict`: Represent a getter function as a mapping.
* `OrderedDict`: Implementation of an ordered dictionary for Python <= 3.6
* `OrderedSet`: Implementation of an ordered set.
* `persistable`: Dict/List types with a `load()` and `save()` function

---

<p align="center">Copyright &copy; 2020 Niklas Rosenstein</p>
